@@ -30,7 +30,7 @@
 #![doc(
     html_logo_url = "https://raw.githubusercontent.com/RustCrypto/meta/master/logo.svg",
     html_favicon_url = "https://raw.githubusercontent.com/RustCrypto/meta/master/logo.svg",
-    html_root_url = "https://docs.rs/crypto-bigint/0.2.9"
+    html_root_url = "https://docs.rs/crypto-bigint/0.2.10"
 )]
 #![forbid(unsafe_code, clippy::unwrap_used)]
 #![warn(missing_docs, rust_2018_idioms, unused_qualifications)]
@@ -45,16 +45,19 @@ mod macros;
 mod array;
 mod checked;
 pub mod limb;
+mod non_zero;
 mod traits;
 mod uint;
 mod wrapping;
 
-pub use crate::{checked::Checked, limb::Limb, traits::*, uint::*, wrapping::Wrapping};
+pub use crate::{
+    checked::Checked, limb::Limb, non_zero::NonZero, traits::*, uint::*, wrapping::Wrapping,
+};
 pub use subtle;
 
 #[cfg(feature = "generic-array")]
 pub use {
-    self::array::{ArrayEncoding, ByteArray},
+    self::array::{ArrayDecoding, ArrayEncoding, ByteArray},
     generic_array::{self, typenum::consts},
 };
 
